from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="lib-gateway-port",
    version="1.2.7",
    author="Gateway Port Development Team",
    author_email="dev@gateway-port.io",
    description="High-performance HTTP gateway and reverse proxy with security features",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/gateway-port/lib-gateway-port",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "Topic :: Internet :: Proxy Servers",
        "Topic :: Internet :: WWW/HTTP :: HTTP Servers",
        "Topic :: Security",
        "Topic :: System :: Networking",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
    keywords="gateway proxy reverse-proxy http server security firewall load-balancer",
    project_urls={
        "Bug Tracker": "https://github.com/gateway-port/lib-gateway-port/issues",
        "Documentation": "https://gateway-port.readthedocs.io",
        "Source": "https://github.com/gateway-port/lib-gateway-port",
    },
)



"""
lib-gateway-port

High-performance HTTP gateway and reverse proxy for Python applications.
"""

__version__ = "1.2.7"
__author__ = "Gateway Port Development Team"
__email__ = "dev@gateway-port.io"

from .gateway import SecurityGateway

__all__ = ["SecurityGateway"]
